Struct OrbitCharacteristics

pub struct OrbitCharacteristics {
    img_dt: I32F32,
    orbit_full_period: usize,
    i_entry: IndexedOrbitPosition,
    mode_switches: usize,
}
Represents the characteristics of an orbital path including imaging frequency, orbital period, and the entry position. This struct provides utilities to initialize and manage orbital parameters over time.

Fields

img_dt: I32F32

The maximum time interval between image captures.

orbit_full_period: usize

The full period of the orbit in terms of iterations.

i_entry: IndexedOrbitPosition

The entry position of the orbit indexed in time and position.

mode_switches: usize

The already performed number of fsm mode switches

Implementations

Source

impl OrbitCharacteristics

pub async fn new(c_orbit: &ClosedOrbit, f_cont: &RwLock<FlightComputer>) -> Self

Creates a new OrbitCharacteristics instance using data from a provided closed orbit and a flight computer.

Arguments
  • c_orbit: A reference to the ClosedOrbit to derive orbital parameters.
  • f_cont: A reference to a thread-safe, asynchronous flight computer instance.
Returns

A new OrbitCharacteristics instance.

Panics

This function will panic if the ClosedOrbit’s period cannot be converted to an usize or i64.

pub fn img_dt(&self) -> I32F32

Retrieves the maximum image capture time interval.

pub fn orbit_full_period(&self) -> usize

Retrieves the full orbital period.

pub fn i_entry(&self) -> IndexedOrbitPosition

Retrieves the indexed entry position of the current orbit entry.

pub fn mode_switches(&self) -> usize

Returns the number of mode switches already performed

pub fn finish(&mut self, now_pos: Vec2D<I32F32>, rationale: &str)

Marks the end of an orbital mode and updates the entry position.

Arguments
  • now: The new IndexedOrbitPosition representing the current state.
pub fn finish_entry(&mut self, now_pos: Vec2D<I32F32>, index: usize)

Marks the end of an orbital mode after re-entering the orbit.

Arguments
  • now_pos: The current position
  • index: The return index where re-entering was performed