pub struct OrbitCharacteristics {
img_dt: I32F32,
orbit_full_period: usize,
i_entry: IndexedOrbitPosition,
mode_switches: usize,
}Expand description
Represents the characteristics of an orbital path including imaging frequency, orbital period, and the entry position. This struct provides utilities to initialize and manage orbital parameters over time.
Fields
img_dt: I32F32The maximum time interval between image captures.
orbit_full_period: usizeThe full period of the orbit in terms of iterations.
i_entry: IndexedOrbitPositionThe entry position of the orbit indexed in time and position.
mode_switches: usizeThe already performed number of fsm mode switches
Implementations
Sourceimpl OrbitCharacteristics
impl OrbitCharacteristics
Sourcepub async fn new(c_orbit: &ClosedOrbit, f_cont: &RwLock<FlightComputer>) -> Self
pub async fn new(c_orbit: &ClosedOrbit, f_cont: &RwLock<FlightComputer>) -> Self
Creates a new OrbitCharacteristics instance using data from a provided closed orbit
and a flight computer.
Arguments
c_orbit: A reference to theClosedOrbitto derive orbital parameters.f_cont: A reference to a thread-safe, asynchronous flight computer instance.
Returns
A new OrbitCharacteristics instance.
Panics
This function will panic if the ClosedOrbit’s period cannot be converted to an
usize or i64.
Sourcepub fn orbit_full_period(&self) -> usize
pub fn orbit_full_period(&self) -> usize
Retrieves the full orbital period.
Sourcepub fn i_entry(&self) -> IndexedOrbitPosition
pub fn i_entry(&self) -> IndexedOrbitPosition
Retrieves the indexed entry position of the current orbit entry.
Sourcepub fn mode_switches(&self) -> usize
pub fn mode_switches(&self) -> usize
Returns the number of mode switches already performed